@@ -32,9 +32,8 @@ module Make (Ast : Camlp4.Sig.Ast) = struct
       let () = Stream.iter (Buffer.add_char buf) strm
       in Buffer.contents buf in
     let magic_len = String.length ast_magic in
-    let buffer = String.create magic_len in
     do {
-      String.blit str 0 buffer 0 magic_len;
+      let buffer = String.sub str 0 magic_len;
       if buffer = ast_magic then ()
       else failwith (Format.sprintf "Bad magic: %S vs %S" buffer ast_magic);
       Marshal.from_string str magic_len;
